@@ -330,7 +330,14 @@ def rasv(word,model,words_list1,words_list2):
             index = words_list1.index(similar_word)
             return words_list2[index]
         else:
-            return "Sorry , I don't know that"
+            closest_index = -1
+            closest_distance = float("inf")
+            for i, w in enumerate(words_list1):
+                distance = abs(len(word) - len(w))
+                if distance < closest_distance:
+                    closest_index = i
+                    closest_distance = distance
+            return words_list2[closest_index]
             #from googlesearch import search
             #import requests
             #from bs4 import BeautifulSoup
@@ -363,6 +370,33 @@ def rasv(word,model,words_list1,words_list2):
 
 
     return get_answer(word, words_list1, words_list2)
+def bert(word,model,words_list1,words_list2):
+    from sentence_transformers import SentenceTransformer, util
+
+    # Load the pre-trained BERT model
+    model = SentenceTransformer('paraphrase-distilroberta-base-v1')
+
+    # Define your sentences
+    sentences = words_list1
+
+    # Encode the sentences into sentence embeddings
+    sentence_embeddings = model.encode(sentences)
+
+    # Define your user input
+    user_input = word
+
+    # Encode the user input into a sentence embedding
+    user_embedding = model.encode(user_input)
+
+    # Calculate the cosine similarity between the user input embedding and the sentence embeddings
+    similarity_scores = util.pytorch_cos_sim(user_embedding, sentence_embeddings)
+
+    # Find the index of the most similar sentence
+    most_similar_sentence_index = similarity_scores.argmax().item()
+
+    # Print the index of the most similar sentence
+    return words_list2[most_similar_sentence_index]
+
 def spimxr(word,model,words_list1,words_list2):
     closest_indices = [-1, -1]
     closest_distances = [float("inf"), float("inf")]
@@ -377,22 +411,69 @@ def spimxr(word,model,words_list1,words_list2):
             closest_indices[1] = i
             closest_distances[1] = distance
     return words_list2[closest_indices[0]], words_list2[closest_indices[1]]
-def mask(prompt,answer,maskdataset1):
-    filename = open(maskdataset1, 'r')
-    file = csv.DictReader(filename)
+def mask(prompt,answer,list1,list2):
+    #filename = open(maskdataset1, 'r')
+    #file = csv.DictReader(filename)
     global mask_list1
     global mask_list2
-    mask_list1 = []
-    mask_list2 = []
+    mask_list1 = list1
+    mask_list2 = list2
     # creating dictreader object
-    for col in file:
-        mask_list1.append(col["mask"])
-        mask_list2.append(col["return"])
-    for i in range(len(mask_list1)):
-        mask_list1[i] = mask_list1[i].lower()
-    for i in range(len(mask_list2)):
-        mask_list2[i] = mask_list2[i].lower()
+    #for col in file:
+        #mask_list1.append(col["mask"])
+        #mask_list2.append(col["return"])
+    #for i in range(len(mask_list1)):
+       # mask_list1[i] = mask_list1[i].lower()
+    #for i in range(len(mask_list2)):
+        #mask_list2[i] = mask_list2[i].lower()
 
+    def find_word_replace_sentence(list1, list2, sentence, prompt):
+        """
+        This function takes in two lists and a sentence, and replaces any instance of "[mask]"
+        in the sentence with the word from list2 at the same index as the word in list1 that matches
+        the given prompt. It then returns the modified sentence.
+        """
+        # Find the index of the first word in list1 that matches the given prompt
+        for i, word in enumerate(list1):
+            if word in prompt:
+                index = i
+                break
+        else:
+            # If no word in list1 matches the given prompt, return the original sentence
+            return sentence
+
+        # Use the index to get the word from list2
+        word_to_replace = list2[index]
+
+        # Replace any instance of "[mask]" in the sentence with the word from list2
+        new_sentence = sentence.replace("[mask]", word_to_replace)
+
+        # Return the modified sentence
+        return new_sentence
+
+    return  find_word_replace_sentence(list1, list2, answer, prompt)
+def masker(word,model,words_list1,words_list2,masklist1,masklist2):
+    def get_similar_word2(input_word, words_list):
+        match = difflib.get_close_matches(input_word, words_list, n=1, cutoff=0.6)
+        if match:
+            return match[0]
+        else:
+            return None
+
+    def get_answer(input_word, words_list1, words_list2):
+        similar_word = get_similar_word2(input_word, words_list1)
+        if similar_word:
+            index = words_list1.index(similar_word)
+            return mask(word,words_list2[index],masklist1,masklist2)
+        else:
+            closest_index = -1
+            closest_distance = float("inf")
+            for i, w in enumerate(words_list1):
+                distance = abs(len(word) - len(w))
+                if distance < closest_distance:
+                    closest_index = i
+                    closest_distance = distance
+            return mask(word, words_list2[closest_index], masklist1, masklist2)
 def load_file_as_function(file_path):
     # Open the file for reading
     importerror(file_path, "model_load()")
@@ -745,6 +826,8 @@ def model_load(modeltype,input, model):
         return spimx3(input, model, words_list1, words_list2)
     elif modeltype == "spimx4":
         return spimx4(input, model, words_list1, words_list2)
+    elif modeltype == "bert":
+        return bert(input, model, words_list1, words_list2)
     elif modeltype == "rasv":
         return rasv(input,model,words_list1,words_list2)
     elif modeltype == "spimxr":
